@@ -6,8 +6,7 @@ use crate::{
 	time::{Duration, Instant},
 	Error,
 	DW3000,
-	configs,
-	Ready,
+	fast_command,
 };
 use super::Awake;
 
@@ -92,17 +91,17 @@ where
 	/// Force the DW3000 into IDLE mode
 	///
 	/// Any ongoing RX/TX operations will be aborted.
-	pub(super) fn force_idle(mut self) -> Result<DW3000<SPI, CS, Ready>, Error<SPI, CS>> {
+	pub fn force_idle(&mut self) -> Result<(), Error<SPI, CS>> {
+		// our probleme on this function is that we never come back to IDLE_PLL with a locked PLL after usng fast command 0
+		
 		self.ll.fast_command(0)?;
-		Ok(DW3000 {
-			ll:    self.ll,
-			seq:   self.seq,
-			state: Ready,
-		})
+		//while self.ll.sys_status().read()?.rcinit() == 0 {}
+		//while self.ll.sys_status().read()?.cplock() == 0 {}
+		Ok(())
 	}
 
 	/// Use fast command ll in hl
-	pub fn fast_cmd(&mut self, fc: configs::FastCommand) -> Result<(), Error<SPI, CS>> {
+	pub fn fast_cmd(&mut self, fc: fast_command::FastCommand) -> Result<(), Error<SPI, CS>> {
 		self.ll.fast_command(fc as u8)?;
 		Ok(())
 	}
